@@ -41,7 +41,7 @@ public:
 
     KScreen::ScreenPtr toKScreenScreen(KScreen::ConfigPtr &parent) const;
     void updateKScreenScreen(KScreen::ScreenPtr &screen) const;
-    void setOutputs(const QList<WaylandOutput*> outputs);
+    void setOutputs(const QList<WaylandOutput*> &outputs);
 
     void setSize(const QSize &size);
     void setOutputCount(int count);
